<?php


namespace FiloBlu\Kpi\Console\Command;

use DateTime;
use Exception;
use FiloBlu\Kpi\Cron\CreateviewsFactory;
use Magento\Framework\App\Area;
use Magento\Framework\App\State;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class CreateviewsCommand
 * @package FiloBlu\Kpi\Console\Command
 */
class CreateviewsCommand extends Command
{
    /**
     * @var CreateviewsFactory
     */
    protected $createViewsFactory;

    /**
     * @var State
     */
    protected $state;

    /**
     * CreateviewsCommand constructor.
     * @param CreateviewsFactory $createViewsFactory
     * @param State $state
     */
    public function __construct(
        CreateviewsFactory $createViewsFactory,
        State $state
    )
    {
        $this->createViewsFactory = $createViewsFactory;
        $this->state = $state;
        parent::__construct();
    }

    /**
     * {@inheritdoc}
     */
    protected function configure()
    {
        $this->setName('kpi:createviews');
        $this->setDescription('Create views KPI');
        parent::configure();
    }

    /**
     * {@inheritdoc}
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {

        try {
            $this->state->setAreaCode(Area::AREA_ADMINHTML);
        } catch (Exception $e) {
            $output->writeln('Area code was already set, skipping!');
        }

        $now = new DateTime();
        $output->writeln('Create views operation start at ' . $now->format('H:i:s') . '. Check the log for details.');
        $this->createViewsFactory->create()->execute();
        $now = new DateTime();
        $output->writeln('End operation at ' . $now->format('H:i:s'));
        return 0;
    }
}